==> fd-help-800.2017.12.14-noarch-1.tar.gz: fd-help/usr/share/doc/fd-help/index.md <==
%%textdomain fatdoghelp

![ ](fatdog64.png)
# Fatdog64 Frequently Asked Questions

[Desktop symbols](tray.md)

[How to connect to a network](Networking.md)

[My Broadcom Wireless does not work](broadcom.md)

[How can I install Fatdog64 to a BIOS machine?](harddrive.md)

The five possible ways to install Fatdog64 to a UEFI machine

 * [Install to a flash drive](uefi-flashdrive.md)
 * [Install to a flash drive (alternative method)](uefi-flashdrive2.md)
 * [Install to a harddisk when UEFI firmware supports multiple boot loaders](uefi-harddrive.md)
 * [Install to a harddisk when UEFI firmware does not support multiple boot loaders →](http://lightofdawn.org/wiki/wiki.cgi/SonyLinuxUefiBoot)
 * [Windows-only: LICK installer (actually this works for BIOS too)](uefi-lick.md)

[Where can I find rEFInd boot loader?](get-refind.md)

[How to add keys to boot with Secure Boot enabled (Windows 8 and 10).](secure-boot.md)

[How does Fatdog's layered filesystem work?](filesystem.md)

[My browser won't save to xxxx or import my bookmarks.](firefox-spot.md)

[/root/spot - why can't my browser access that directory?](spot.md)

[I'm auto logged in as root, what's up with that?](login.md)

[How do I install extra packages for Fatdog?](fd-packages.md)

[I have amassed a large collection of pet packages from earlier Fatdogs, how do I use them now?](fd-packages.md)

[How can I share files with other computers on my network?](sharing.md)

[My laptop's touch pad ???](touchpad.md)

[Blank screen! (or texts are too small.)](screen.md)

[My screen brightness controls don't work.](brightness.md)

[No sound!](sound.md)

[Why doesn't this Debian/Ubuntu package work?](Debian.md)

[How can I make a new package?](pet-package.md)

[How can I make a new SFS package?](sfs-package.md)

[How can I recompile one kernel module?](kernel-module.md)

[How can I replace the kernel modules in the initrd?](initrd.md)

[How can I use a different kernel.](kernel.md)

[How to temporarily boot with a different kernel](temp-boot-kernel.md)

[Basic keyboard short cuts.](keys.md)

[How to use Fatdog64's built in sandbox environment.](sandbox.md)

[How to use the User Mode Linux (UML) environment.](uml.md)

[Boot options.](boot-options.md)

[Humongous initrd (or, why does my computer boot slowly?)](huge-initrd.md)

[Printing problems?](http://murga-linux.com/puppy/viewtopic.php?p=628636)

[How to play BluRays](bluray.md)

[Found a bug?](bugs.md)

[How to enable the firewall](firewall.md)

[How to change default programs (default browser, default editor, etc)?](defaults.md)

[My savefile is not loaded after reboot!](no-savefile.md)

[Clean desktop:  I don't like it. How to put program icons back on the desktop?](clean-desktop.md)

[How can I update my Browser or Flash Player?](updates.md)

[Can I use Netflix with Fatdog64?](netflix.md)

[Small lines or video noise in Google Chrome.](chrome.md)

[How can I enlarge my savefile?](enlarge-savefile.md)

[Bad 2d performance or tearing with Radeon graphics.](radeon.md)

[OpenGL 2.1 not supported on Intel graphics](intel-graphics.md)

[Desktop takes a long time to show up on old Intel graphics](intel-graphics.md)

[Kernel task eats 100% of my CPU or my Mac is running super hot while doing nothing](disable-gpe.md)

[Suspend and hibernate](suspend.md)

[Character are shown as boxes in (urxvt) terminal](urxvt.md)

[Bluetooth issues](bluetooth.md)

[Miscellaneous other known issues](misc.md)

[What about foreign languages?](localize.md)

---

[More links](links.md)



[Fatdog's home](home.md) 

![ ](fatdog64.png)

==> fd-help-812.2020.08.26-noarch-1.tar.gz: fd-help/usr/share/doc/fd-help/index.md <==
%%textdomain fatdoghelp

![ ](fatdog64.png)
# Fatdog64 Frequently Asked Questions

[Primer for Puppy Linux Users](p4p-index.md)

[Desktop symbols](tray.md)

[How to connect to a network](Networking.md)

[My Broadcom Wireless does not work](broadcom.md)

[How can I install Fatdog64 to a BIOS machine?](harddrive.md)

The five possible ways to install Fatdog64 to a UEFI machine

 * [Install to a flash drive](uefi-flashdrive.md)
 * [Install to a flash drive (alternative method)](uefi-flashdrive2.md)
 * [Install to a harddisk when UEFI firmware supports multiple boot loaders](uefi-harddrive.md)
 * [Install to a harddisk when UEFI firmware does not support multiple boot loaders →](http://lightofdawn.org/wiki/wiki.cgi/SonyLinuxUefiBoot)
 * [Windows-only: LICK installer (actually this works for BIOS too)](uefi-lick.md)

[How to install Fatdog64 to a flash drive that works for both BIOS and UEFI machines](usb-boot.md)

[Where can I find rEFInd boot loader?](get-refind.md)

[How to add keys to boot with Secure Boot enabled (Windows 8 and 10).](secure-boot.md)

[How does Fatdog's layered filesystem work?](filesystem.md)

[My browser won't save to xxxx or import my bookmarks.](firefox-spot.md)

[/root/spot - why can't my browser access that directory?](spot.md)

[I'm auto logged in as root, what's up with that?](login.md)

[How do I install extra packages for Fatdog?](fd-packages.md)

[I have amassed a large collection of pet packages from earlier Fatdogs, how do I use them now?](fd-packages.md)

[How can I share files with other computers on my network?](sharing.md)

[My laptop's touch pad ???](touchpad.md)

[Blank screen! (or texts are too small.)](screen.md)

[My screen brightness controls don't work.](brightness.md)

[No sound!](sound.md)

[Why doesn't this Debian/Ubuntu package work?](Debian.md)

[How can I make a new package?](pet-package.md)

[How can I make a new SFS package?](sfs-package.md)

[How can I recompile one kernel module?](kernel-module.md)

[How can I replace the kernel modules in the initrd?](initrd.md)

[How can I use a different kernel.](kernel.md)

[How to temporarily boot with a different kernel](temp-boot-kernel.md)

[Basic keyboard short cuts.](keys.md)

[How to use Fatdog64's built in sandbox environment.](sandbox.md)

[How to use the User Mode Linux (UML) environment.](uml.md)

[Boot options.](boot-options.md)

[Humongous initrd (or, why does my computer boot slowly?)](huge-initrd.md)

[Printing problems?](printing.md)

[How to play BluRays](bluray.md)

[Found a bug?](bugs.md)

[How to enable the firewall](firewall.md)

[How to change default programs (default browser, default editor, etc)?](defaults.md)

[My savefile is not loaded after reboot!](no-savefile.md)

[Clean desktop:  I don't like it. How to put program icons back on the desktop?](clean-desktop.md)

[How can I update my Browser or Flash Player?](updates.md)

[Can I use Netflix with Fatdog64?](netflix.md)

[Small lines or video noise in Google Chrome.](chrome.md)

[How can I enlarge my savefile?](enlarge-savefile.md)

[Bad 2d performance or tearing with Radeon graphics.](radeon.md)

[OpenGL 2.1 not supported on Intel graphics](intel-graphics.md)

[Desktop takes a long time to show up on old Intel graphics](intel-graphics.md)

[Kernel task eats 100% of my CPU or my Mac is running super hot while doing nothing](disable-gpe.md)

[Suspend and hibernate](suspend.md)

[Character are shown as boxes in (urxvt) terminal](urxvt.md)

[Bluetooth issues](bluetooth.md)

[How to listen to music using bluetooth speakers or headphones](bluetooth-audio.md)

[NetBIOS (Samba) name resolution](winbindd.md)

[How to change desktop icon themes?](desktop-icon-themes.md)

[How to find firmware for your devices](firmware.md)

[Help! I cannot choose my savefile, my keyboard is unresponsive at boot time!](boot-keyboard-problem.md)

[My computer slows down after updating to the latest Fatdog ...](cpu-mitigations.md)

[Miscellaneous other known issues](misc.md)

[What about foreign languages?](localize.md)

---

[More links](links.md)



[Fatdog's home](home.md) 

![ ](fatdog64.png)
